@@ -40,6 +40,32 @@ class APIConnection(HttpConnection):
         if resp:
             return json_load(resp)
 
+    def describe_jobs(self, jobs=None,
+                            status=None,
+                            job_action=None,
+                            offset=None,
+                            limit=None,
+                            **ignore):
+        """ Describe jobs.
+
+        @param jobs: the IDs of job you want to describe.
+        @param status: valid values include pending, working, failed, successful.
+        @param job_action: the action of job you want to describe.
+        @param offset: the starting offset of the returning results.
+        @param limit: specify the number of the returning results.
+        """
+        action = const.ACTION_DESCRIBE_JOBS
+        valid_keys = ['jobs', 'status', 'job_action', 'offset', 'limit']
+        body = filter_out_none(locals(), valid_keys)
+        if not self.req_checker.check_params(body,
+                required_params=[],
+                integer_params=["offset", "limit"],
+                list_params=["jobs"]
+                ):
+            return None
+
+        return self.send_request(action, body)
+
     def describe_images(self, images = None,
                               os_family = None,
                               processor_type = None,
@@ -149,6 +175,7 @@ class APIConnection(HttpConnection):
         @param instances : the array of IDs of instances
         @param image_id : ID of the image which is used to launch this instance.
         @param instance_type: The instance type.
+                              See: https://docs.qingcloud.com/api/common/includes/instance_type.html
         @param status : Status of the instance, including pending, running, stopped, terminated.
         @param verbose: the number to specify the verbose level, larger the number, the more detailed information will be returned.
         @param search_word: the combined search column.
@@ -188,12 +215,12 @@ class APIConnection(HttpConnection):
                             **ignore):
         """ Create one or more instances.
         @param image_id : ID of the image you want to use, "img-12345"
-        @param instance_type: What kind of instance you want to launch. "micro", "small", "medium", "large".
+        @param instance_type: What kind of instance you want to launch.
+                              See: https://docs.qingcloud.com/api/common/includes/instance_type.html
         @param cpu: cpu core number.
         @param memory: memory size in MB.
         @param instance_name: a meaningful short name of instance.
         @param count : The number of instances to launch, default 1.
-        @param instance_type : e.g., "micro", "small", "medium", "large".
         @param vxnets : The IDs of vxnets the instance will join.
         @param security_group: The ID of security group that will apply to instance.
         @param login_mode: ssh login mode, "keypair" or "passwd"
@@ -326,6 +353,7 @@ class APIConnection(HttpConnection):
         """ Resize one or more instances
         @param instances: the IDs of the instances you want to resize.
         @param instance_type: defined by qingcloud.
+                              See: https://docs.qingcloud.com/api/common/includes/instance_type.html
         @param cpu: cpu core number.
         @param memory: memory size in MB.
         """
@@ -1001,6 +1029,7 @@ class APIConnection(HttpConnection):
             @param image: filter by image ID.
             @param instances: filter by instance ID.
             @param instance_type: filter by instance type
+                                  See: https://docs.qingcloud.com/api/common/includes/instance_type.html
             @param status: filter by status
             @param offset: the starting offset of the returning results.
             @param limit: specify the number of the returning results.
@@ -1215,6 +1244,34 @@ class APIConnection(HttpConnection):
 
         return self.send_request(action, body)
 
+    def modify_router_static_attributes(self, router_static,
+                                              router_static_name=None,
+                                              val1=None,
+                                              val2=None,
+                                              val3=None,
+                                              val4=None,
+                                              val5=None,
+                                              val6=None,
+                                              disabled=None,
+                                              **ignore):
+        """ Modify router static attributes.
+            @param router_static: the ID of router static you want to modify its attributes.
+            @param val1 - val6: please see the doc. https://docs.qingcloud.com/api/router/modify_router_static_attributes.html
+            @param disabled: disable the static when this is 1, or 0 to enable it.
+        """
+        action = const.ACTION_MODIFY_ROUTER_STATIC_ATTRIBUTES
+        valid_keys = ['router_static', 'router_static_name', 'disabled',
+                'val1', 'val2', 'val3', 'val4', 'val5', 'val6']
+        body = filter_out_none(locals(), valid_keys)
+        if not self.req_checker.check_params(body,
+                required_params=['router_static'],
+                integer_params=[],
+                list_params=[]
+                ):
+            return None
+
+        return self.send_request(action, body)
+
     def describe_router_vxnets(self, router=None,
                                      vxnet=None,
                                      limit=None,
