@@ -15,6 +15,8 @@
 # =========================================================================
 
 ########## API Actions ##########
+# jobs
+ACTION_DESCRIBE_JOBS = "DescribeJobs"
 
 # images
 ACTION_DESCRIBE_IMAGES = "DescribeImages"
@@ -84,6 +86,7 @@ ACTION_POWERON_ROUTERS = "PowerOnRouters"
 ACTION_DESCRIBE_ROUTERS = "DescribeRouters"
 ACTION_DESCRIBE_ROUTER_VXNETS = "DescribeRouterVxnets"
 ACTION_MODIFY_ROUTER_ATTRIBUTES = "ModifyRouterAttributes"
+ACTION_MODIFY_ROUTER_STATIC_ATTRIBUTES = "ModifyRouterStaticAttributes"
 ACTION_DESCRIBE_ROUTER_STATICS = "DescribeRouterStatics"
 ACTION_ADD_ROUTER_STATICS = "AddRouterStatics"
 ACTION_DELETE_ROUTER_STATICS = "DeleteRouterStatics"
